import { EventEmitter, NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { YaEvent } from '../../interfaces/ya-event';
import { YaReadyEvent } from '../../interfaces/ya-ready-event';
import { YaMapComponent } from '../ya-map/ya-map.component';
import * as i0 from "@angular/core";
/**
 * The `ya-panorama` component wraps `ymaps.panorama.Player` class from the Yandex.Maps API.
 * You can configure it via the component's inputs.
 * Events can be bound using the outputs of the component.
 *
 * @example
 * ```html
 * <ya-map>
 *   <ya-panorama [point]="[59.938557, 30.316198]" layer="yandex#airPanorama"></ya-panorama>
 * </ya-map>
 * ```
 */
export declare class YaPanoramaDirective implements OnInit, OnChanges, OnDestroy {
    private readonly ngZone;
    private readonly yaMapComponent;
    private readonly destroy$;
    private readonly eventManager;
    private player?;
    /**
     * The point for searching for nearby panoramas.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.locate.html#panorama.locate__param-point}
     */
    point: number[];
    /**
     * The layer to search for panoramas.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.locate.html#panorama.locate__param-options.layer}
     */
    layer?: ymaps.panorama.Layer;
    /**
     * Player options.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#panorama.Player__param-options}
     */
    options?: ymaps.panorama.IPlayerOptions;
    /**
     * Panorama instance is created.
     */
    ready: EventEmitter<YaReadyEvent<ymaps.panorama.Player>>;
    /**
     * The player was closed by the user or destroyed using the panorama.Player.destroy method.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#event_detail__event-destroy}
     */
    destroy: Observable<YaEvent<ymaps.panorama.Player>>;
    /**
     * The view direction changed.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#event_detail__event-directionchange}
     */
    directionchange: Observable<YaEvent<ymaps.panorama.Player>>;
    /**
     * An error occurred during operation of the player. The user will be shown the appropriate screen.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#event_detail__event-error}
     */
    yaerror: Observable<YaEvent<ymaps.panorama.Player>>;
    /**
     * The panorama player switched to full-screen mode.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#event_detail__event-fullscreenenter}
     */
    fullscreenenter: Observable<YaEvent<ymaps.panorama.Player>>;
    /**
     * The panorama player exited full-screen mode.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#event_detail__event-fullscreenexit}
     */
    fullscreenexit: Observable<YaEvent<ymaps.panorama.Player>>;
    /**
     * The user clicked on an expanded marker.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#event_detail__event-markercollapse}
     */
    markercollapse: Observable<YaEvent<ymaps.panorama.Player>>;
    /**
     * The user clicked on a collapsed marker.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#event_detail__event-markerexpand}
     */
    markerexpand: Observable<YaEvent<ymaps.panorama.Player>>;
    /**
     * The user's cursor hovered over a marker.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#event_detail__event-markermouseenter}
     */
    markermouseenter: Observable<YaEvent<ymaps.panorama.Player>>;
    /**
     * The user's cursor left a marker.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#event_detail__event-markermouseleave}
     */
    markermouseleave: Observable<YaEvent<ymaps.panorama.Player>>;
    /**
     * The open panorama changed.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#event_detail__event-panoramachange}
     */
    panoramachange: Observable<YaEvent<ymaps.panorama.Player>>;
    /**
     * The size of the viewport has been changed.
     * {@link https://yandex.com/dev/maps/jsapi/doc/2.1/ref/reference/panorama.Player.html#event_detail__event-spanchange}
     */
    spanchange: Observable<YaEvent<ymaps.panorama.Player>>;
    constructor(ngZone: NgZone, yaMapComponent: YaMapComponent);
    /**
     * Handles input changes and passes them in API.
     * @param changes
     */
    ngOnChanges(changes: SimpleChanges): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Destructs state and passes it in API.
     * @param options
     * @param player
     */
    private setOptions;
    /**
     * Searches for a panorama and returns first
     */
    private createPanorama;
    static ɵfac: i0.ɵɵFactoryDeclaration<YaPanoramaDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YaPanoramaDirective, "ya-panorama", never, { "point": "point"; "layer": "layer"; "options": "options"; }, { "ready": "ready"; "destroy": "destroy"; "directionchange": "directionchange"; "yaerror": "yaerror"; "fullscreenenter": "fullscreenenter"; "fullscreenexit": "fullscreenexit"; "markercollapse": "markercollapse"; "markerexpand": "markerexpand"; "markermouseenter": "markermouseenter"; "markermouseleave": "markermouseleave"; "panoramachange": "panoramachange"; "spanchange": "spanchange"; }, never, never, false, never>;
}
